Age-specific expected densities based on DRM.
Arguments
- drm
A
listobject containing the output from the fit_drm function.- new_data
a
data.framewith the dataset at which we wish to obtain predictions.- f_test
a
matrixinforming the instantaneous fishing mortality rates at each age (columns) and timepoint (rows).- cores
number of threads used for the forecast. If four chains were used in the
drm, then four (or less) threads are recommended.- ...
params to be passed to
age_edens