This function identifies the parameters necessary for carrying out predictions based on the data used to fit a DRM (or SDM).
Arguments
- data_list
a
listused as input for model fitting. Typically, the output from the make_data function.- model
a
characterindicating which model predictions are sought for. This input admits two possible entries: "drm" (default) or "sdm".