Skip to contents

Constructs an object of class adrm from a list, after validating its structure. Note that, this function is mostly for internal usage. adrm stands for age-structured dynamic range model.

Usage

new_adrm(x = list())

Arguments

x

A list that has the required fields for an 'adrm' object. Defaults to an empty list.

Value

An object of class adrm.