Skip to contents

Constructs an object of class aesd from a list, after validating its structure. Note that this function is mostly for internal usage.

Usage

new_aesd(x = list())

Arguments

x

A list that has the required fields for a 'aesd' object. Defaults to an empty list.

Value

An object of class aesd.