Skip to contents

Constructs an object of class pred_drmr from a list, after validating its structure. Note that this function is mostly for internal usage.

Usage

new_pred_drmr(x = list())

Arguments

x

A list that has the required fields for a 'pred_drmr' object. Defaults to an empty list.

Value

An object of class pred_drmr.