Skip to contents

Constructs an object of class sdm from a list, after validating its structure. Note that, this function is mostly for internal usage. sdm stands for species distribution model.

Usage

new_sdm(x = list())

Arguments

x

A list that has the required fields for an 'sdm' object. Defaults to an empty list.

Value

An object of class sdm.