Returns default for a given algorithm
Usage
default_algo(algorithm = "nuts", algo_args = list())Arguments
- algorithm
a
characterspecifying the algorithm used for inference. Default isnuts(the default MCMC in Stan). The remaining options are different flavors of variational bayes algorithms: "vb" (for ADVI), "pathfinder" (for Pathfinder), "laplace" (normal approximation centered at the mode of the posterior) or "optimize" for (penalized) MLEs.- algo_args
a
listwith arguments for the sampling algorithms. For instance,tol_rel_objfor variational inference.