Mirrors the behavior of cmdstanr's $draws method
to retrieve the samples from the posterior distribution of the models'
parameters.
Usage
draws(x, ...)
# S3 method for class 'drmrmodels'
draws(
x,
variables = NULL,
inc_warmup = FALSE,
format = getOption("cmdstanr_draws_format", "draws_array"),
...
)Arguments
- x
An object of class
adrmorsdm.- ...
currently ignored.
- variables
a string vector with the name of the variables for which we want to obtain posteriors samples (defaults to the same variables as the
summarymethods).- inc_warmup
a boolean indicating whether the warmup samples should be retrieved as well. Defaults to
FALSE.- format
A string. See cmdstanr $draws documentation.