Relationships with covariates
Arguments
- drm
the output of a
fit_drm()call.- newdata
a
data.framewith the values of the environmental variables at which we wish to estimate the recruitment, survival, or absence probabilities.
Value
a data.frame with the samples the recruitment (or survival,
or absence probabilities) posterior distribution.