Constructs an object of class adrm from a list, after validating its
structure. Note that, this function is mostly for internal usage. adrm
stands for age-structured dynamic range model.
Usage
new_adrm(x = list())Constructs an object of class adrm from a list, after validating its
structure. Note that, this function is mostly for internal usage. adrm
stands for age-structured dynamic range model.
new_adrm(x = list())