Constructs an object of class aesd from a list, after validating its
structure. Note that this function is mostly for internal usage.
Usage
new_aesd(x = list())Constructs an object of class aesd from a list, after validating its
structure. Note that this function is mostly for internal usage.
new_aesd(x = list())