Constructs an object of class pred_drmr from a list, after validating its
structure. Note that this function is mostly for internal usage.
Usage
new_pred_drmr(x = list())Constructs an object of class pred_drmr from a list, after validating its
structure. Note that this function is mostly for internal usage.
new_pred_drmr(x = list())