Constructs an object of class sdm from a list, after validating its
structure. Note that, this function is mostly for internal usage. sdm
stands for species distribution model.
Usage
new_sdm(x = list())Constructs an object of class sdm from a list, after validating its
structure. Note that, this function is mostly for internal usage. sdm
stands for species distribution model.
new_sdm(x = list())