Provides trace and density plots for the posterior draws of a DRM (or SDM) model.
Arguments
- x
An object of class
drmrmodels. Typically, the output of afit_drmorfit_sdmcall.- variables
An optional character vector of parameter names to plot. If
NULL, plots all.- type
A character vector specifying which plots to draw:
"trace","density", or both.- ask
Logical; if
TRUE, the user is prompted before displaying the next plot. IfNULL(the default), it is calculated dynamically based on the current graphical layout.- ...
Additional graphical parameters passed to
plot.