Generate samples from the prior predictive distribution of model parameters
Source:R/data-gen.R
pp_sim.RdGenerates samples from the prior distributions of the model parameters. This is primarily used for prior predictive checks or to generate initial values for MCMC.
Arguments
- dat
A
listcontaining the data and prior parameters, typically generated bymake_data()ormake_data_sdm().- model
A
characterstring specifying the model type. Must be either "drm" or "sdm". Defaults to "drm".- selectivity
a numeric
vectorwith the same length as the number of age-groups.- ...
parameters passed on to
pop_dyn.