Considering a new dataset (across the same patches), computes
forecasts based on the DRM passed as drm.
Arguments
- drm
A
listobject containing the output from the fit_drm function.- new_data
a
data.framewith the dataset at which we wish to obtain predictions.- past_data
a
data.framewith the dataset last year used in model fitting. Only needed whenf_testis not missing or when estimating survival.- f_test
a
matrixinforming the instantaneous fishing mortality rates at each age (columns) and timepoint (rows).- seed
a seed used for the forecasts. Forecasts are obtained through Monte Carlo samples from the posterior predictive distribution. Therefore, a
seedis needed to ensure the results' reproducibility.- cores
number of threads used for the forecast. If four chains were used in the
drm, then four (or less) threads are recommended.
Value
an object of class "CmdStanGQ" containing samples for the
posterior predictive distribution for forecasting.